@@ -151,16 +151,18 @@
 #'              every pressure value (in press_seq) whether the slope is considered
 #'              as zero for the proportion calculation (see the last section in
 #'              \emph{Details}).}
-#'   \item{\code{press_seq}}{A list-column with sequences of evenly spaced pressure
-#'              values (with the length of the time series).}
+#'   \item{\code{press_seq}}{A list-column with sequences of 100 evenly spaced
+#'              pressure values.}
 #'   \item{\code{pred}}{A list-column with the predicted indicator responses
-#'              averaged across all bootstraps.}
+#'              averaged across all bootstraps (for the 100 equally spaced
+#'              pressure values).}
 #'   \item{\code{pred_ci_up}}{A list-column with the upper confidence limit of the
 #'              bootstrapped predictions.}
 #'   \item{\code{pred_ci_low}}{A list-column with the lower confidence limit of the
 #'              bootstrapped predictions.}
 #'   \item{\code{deriv1}}{A list-column with the first derivatives of the indicator
-#'              responses averaged across all bootstraps.}
+#'              responses averaged across all bootstraps (for the 100 equally spaced
+#'              pressure values).}
 #'   \item{\code{deriv1_ci_up}}{A list-column with the upper confidence limit of the
 #'              bootstrapped first derivatives.}
 #'   \item{\code{deriv1_ci_low}}{A list-column with the lower confidence limit of the
@@ -237,7 +239,7 @@ calc_deriv <- function(init_tbl, mod_tbl, edf_filter = 1.5,
     var_to_check = c("id", "ind", "press", "corrstruc",
       "edf", "p_val", "model"), dt_to_check = c("integer",
       "character", "character", "character",
-      "numeric", "numeric", "list"))
+      "double", "double", "list"))
 
   # Test if there are any ids with NAs in models (if,
   # e.g., GAMMs were manually selected and
@@ -305,7 +307,7 @@ calc_deriv <- function(init_tbl, mod_tbl, edf_filter = 1.5,
 
   # Correct method (2 options)?
   if (is.null(method)) {
-    stop("The method must be either `conditional bootstrap` or `approx_deriv`.")
+    stop("The method must be either 'cond_boot' or 'approx_deriv'.")
   } else {
     if (!method %in% c("cond_boot", "approx_deriv")) {
       stop("The method must be either 'cond_boot' or 'approx_deriv'.")
@@ -372,10 +374,8 @@ calc_deriv <- function(init_tbl, mod_tbl, edf_filter = 1.5,
     filt <- mod_tbl[is_value(mod_tbl$edf) & is_value(mod_tbl$p_val) &
       mod_tbl$edf > edf_filter & mod_tbl$p_val <=
       sign_level, ]
-    unfilt <- mod_tbl[!mod_tbl$id %in% filt$id,
-      ]
-    filt_init <- init_tbl[init_tbl$id %in% filt$id,
-      ]
+    unfilt <- mod_tbl[!mod_tbl$id %in% filt$id, ]
+    filt_init <- init_tbl[init_tbl$id %in% filt$id, ]
 
     # Assign prop of NA or 1.00 to unfiltered ids (if
     # not (NA if not sign.)
