@@ -39,16 +39,18 @@
 #' @return
 #' The function returns the input model tibble with the following 9 columns added
 #' \describe{
-#'   \item{\code{press_seq}}{A list-column with sequences of evenly spaced pressure
-#'              values (with the length of the time series).}
+#'   \item{\code{press_seq}}{A list-column with sequences of 100 evenly spaced pressure
+#'              values.}
 #'   \item{\code{pred}}{A list-column with the predicted indicator responses
-#'              averaged across all bootstraps.}
+#'              averaged across all bootstraps (for the 100 equally spaced
+#'              pressure values).}
 #'   \item{\code{pred_ci_up}}{A list-column with the upper confidence limit of the
 #'              bootstrapped predictions.}
 #'   \item{\code{pred_ci_low}}{A list-column with the lower confidence limit of the
 #'              bootstrapped predictions.}
 #'   \item{\code{deriv1}}{A list-column with the first derivatives of the indicator
-#'              responses averaged across all bootstraps.}
+#'              responses averaged across all bootstraps (for the 100 equally spaced
+#'              pressure values).}
 #'   \item{\code{deriv1_ci_up}}{A list-column with the upper confidence limit of the
 #'              bootstrapped first derivatives.}
 #'   \item{\code{deriv1_ci_low}}{A list-column with the lower confidence limit of the
@@ -102,7 +104,7 @@ cond_boot <- function(init_tbl, mod_tbl, excl_outlier,
   # predictions
   dat$press_seq <- purrr::map(.x = dat$press_train,
     .f = ~seq(min(.x, na.rm = TRUE), max(.x, na.rm = TRUE),
-      length.out = length(.x)))
+      length.out = 100))
   # Get delta and generate press_seq plus/minus delta
   # for deriv calculation
   dat$delta <- purrr::map_dbl(.x = dat$press_seq,
